transfer_opt_default

Macro transfer_opt_default 

macro_rules! transfer_opt_default {
    ($val:ident, $struct_source:ident, $receiver:ident) => { ... };
}
Transfers a mutable pointer to a hashmap entry, or fills in with a default if missing.

Assumption: $receiver is HashMap<String,String>. If, and only if, $has_receiver does not have a value at slot $val, and $struct_source has a set value at $val, then transfers (with ownership) the $val field of a $struct_source into the $receiver.