CoreOptions

Struct CoreOptions 

pub struct CoreOptions {
    pub model: Option<Model>,
    pub verbosity: Option<i32>,
    pub strict: Option<bool>,
    pub include_comments: Option<bool>,
    pub include_styles: Option<bool>,
    pub nomathparse: Option<bool>,
    pub source_map: Option<bool>,
    pub documentid: Option<String>,
    pub search_paths: Option<Vec<String>>,
    pub graphics_paths: Option<Vec<String>>,
    pub input_encoding: Option<String>,
    pub preload: Option<Vec<String>>,
}
Configuration for the Core processing

Fields

model: Option<Model>

a custom schema-induced model (default is None) for the final XML

verbosity: Option<i32>

default is 0, sub-zero values are quiet, positive values are verbose

strict: Option<bool>

strict error-reporting (is this still used?)

include_comments: Option<bool>

toggle preserving comments in the XML on/off

include_styles: Option<bool>

toggle loading raw .sty modules on/off

nomathparse: Option<bool>

disable math parsing (enabled by default)

source_map: Option<bool>

enable source-locator (--source-map) tracking + emission (off by default). See docs/performance/SOURCE_PROVENANCE.md.

documentid: Option<String>

an optional, fixed id prefix for all xml:id attributes

search_paths: Option<Vec<String>>

the list of paths used for loading TeX sources and packages

graphics_paths: Option<Vec<String>>

the list of paths used for loading graphics assets

input_encoding: Option<String>

set an explicit encoding of the input text

preload: Option<Vec<String>>

a list of package names to preload before processing start