macro_rules! NewDefault {
($name:ident, $($key:ident => $value:expr_2021),*) => { ... };
}Expand description
given a struct $name, create a new instance of it using the given key=>val pairs
and complete the remaining entries via the Default instance